<!-- 新增编辑弹窗 -->
<template>
    <j-modal
        v-if="visible"
        :title="props.title"
        :maskClosable="false"
        destroy-on-close
        visible
        @ok="submitData"
        @cancel="close"
        okText="确定"
        cancelText="取消"
    >
        <j-form
            layout="vertical"
            ref="formRef"
            :rules="rules"
            :model="formModel"
        >
            <j-form-item label="名称" name="name">
                <!-- <j-select
                    style="width: 100%"
                    v-model:value="formModel.name"
                    :options="[
                        { value: '1000000000000000051', label: '四川' },
                    ]"
                    placeholder="请选择省份"
                /> -->
                <j-input
                    v-model:value="formModel.name"
                    :maxlength="64"
                    placeholder="请输入名称"
                    allowClear
                />
            </j-form-item>
            <j-form-item label="序号" name="sortIndex">
                <j-input
                    v-model:value="formModel.sortIndex"
                    :maxlength="64"
                    placeholder="请输入序号"
                    allowClear
                />
            </j-form-item>
            <j-form-item label="备注">
                <j-input
                    v-model:value="formModel.describe"
                    :maxlength="64"
                    placeholder="请输入备注"
                    allowClear
                />
            </j-form-item>
        </j-form>
    </j-modal>
</template>
<script setup lang="ts" name="modifyModal">
import { PropType } from 'vue';
import { Form, message } from 'jetlinks-ui-components';
import { queryRegion, saveTree, updateTree } from '@/api/warehouse/region';

const emits = defineEmits(['refresh']);
const formRef = ref();
const useForm = Form.useForm;
const props = defineProps({
    formData: {
        type: Object as PropType<Record<string, any>>,
        default: () => {

        },
    },
    title: {
        type: String,
        defult: '新增区域',
    },
    isAdd: {
        type: Number,
        default: 0,
    },
    isChild: {
        type: Number,
        default: 0,
    },
});
interface formState {
    id?: string;
    name: string;
    sortIndex: number | null;
    describe: string;
    city?: string;
    region?: string;
    parentId?: string;
}
const listData = ref([]);
const childArr = ref([]);
const arr = ref([]);
const updateObj = ref({});
const addObj = ref({});
const addParams = ref({});
/**
 * 表单数据
 */
const formModel = ref<formState>({
    name: '',
    sortIndex: null,
    describe: "",
    city: "",
    region: '',
});
const rules = ref({
    province: [{ required: true, message: '请选择省份', trigger: 'change' }],
    city: [{ required: true, message: '请选择城市', trigger: 'change' }],
    region: [{ required: true, message: '请选择区域', trigger: 'change' }],
});
const visible = ref(false);
const { resetFields, validate, validateInfos } = useForm(
    formModel.value,
    rules.value,
);
/**
 * 提交数据
 */
const submitData = async () => {
    formRef.value.validate().then(async () => {
        addParams.value = {};
        // console.log("submitData:", formModel, props);
        if (props.isAdd === 0) {
            addParams.value = {
                ...formModel.value,
                sortIndex: Number(formModel.value.sortIndex)
            };
            const res = await saveTree(addParams.value);
            if (res.status === 200) {
                message.success('操作成功！');
                visible.value = false;
                emits('refresh');
            } else {
                message.error('操作失败！');
            }
        } else if (props.isAdd === 2) {
            const id = formModel.value.id || "";
            const updateParams = {
                ...formModel.value,
                sortIndex: Number(formModel.value.sortIndex)
            };
            delete updateParams.parentId;
            const res = await updateTree(id, updateParams);
            if (res.status === 200) {
                message.success('操作成功！');
                visible.value = false;
                emits('refresh');
            } else {
                message.error('操作失败！');
            }
        }
    });
};
/**
 * 显示弹窗
 */
const show = async (row: any) => {
    // console.log("show:", row, props.isAdd);
    //新增
    if (props.isAdd === 0) {
        formModel.value = {
            parentId: row.id || "",
            name: "",
            sortIndex: null,
            describe: "",
        };
        visible.value = true;
    } else if (props.isAdd === 2) {
        updateObj.value = row;
        // 编辑
        formModel.value = {
            parentId: row.parentId,
            id: row.id,
            name: row.name,
            sortIndex: row.sortIndex,
            describe: row.describe,
        };
        visible.value = true;
    }
};

/**
 * 排序
 */
 const compare = (property: any) => {
        return function (obj1: any, obj2: any) {
            var value1 = obj1[property];
            var value2 = obj2[property];
            return value1 - value2; // 升序
        };
    };
/**
 * 关闭弹窗
 */
const close = () => {
    visible.value = false;
    resetFields();
};
//监听项目ID
watch([() => props.isAdd], () => {}, { immediate: false, deep: true });
defineExpose({
    show: show,
});
</script>
<style></style>
